@@ -429,8 +429,10 @@ cd_cache_new (const char *dev,
     GMount *mount;
 
     mount = g_volume_get_mount (volume);
-    cache->content_types = g_mount_guess_content_type_sync (mount, FALSE, NULL, NULL);
-    g_object_unref (mount);
+    if (mount) {
+      cache->content_types = g_mount_guess_content_type_sync (mount, FALSE, NULL, NULL);
+      g_object_unref (mount);
+    }
   }
 
   return cache;
@@ -446,8 +448,10 @@ cd_cache_has_medium (CdCache *cache)
     return FALSE;
 
   drive = g_volume_get_drive (cache->volume);
-  if (drive == NULL)
-    return FALSE;
+  if (drive == NULL) {
+    /* No drive, so not something that can have a medium */
+    return TRUE;
+  }
   retval = g_drive_has_media (drive);
   g_object_unref (drive);
 
